@@ -22,6 +22,12 @@ print "Fedora license string: $fedora_license_string\n";
 print 'Format: '.$obj->format."\n";
 print "Contain licenses:\n";
 print join "\n", map { '- '. $_ } $obj->licenses;
+print "\n";
+if ($obj->exceptions) {
+        print "Contain exceptions:\n";
+        print join "\n", map { '- '. $_ } $obj->exceptions;
+        print "\n";
+}
 
 # Output with 'MIT' input:
 # Fedora license string: MIT
@@ -44,4 +50,12 @@ print join "\n", map { '- '. $_ } $obj->licenses;
 # - Artistic 2.0
 # - GPL+
 # - GPLv2
-# - MIT
\ No newline at end of file
+# - MIT
+
+# Output with 'LGPL-3.0-only WITH LGPL-3.0-linking-exception' input:
+# Fedora license string: LGPL-3.0-only WITH LGPL-3.0-linking-exception
+# Format: 2
+# Contain licenses:
+# - LGPL-3.0-only
+# Contain exceptions:
+# - LGPL-3.0-linking-exception
\ No newline at end of file
